@@ -3,6 +3,7 @@ from fastai.vision.all import *
 import fastai
 import torchvision.models as models
 import shutil
+import os
 
 
 def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, bs=32, size=224, confidence=0.8):
@@ -27,6 +28,8 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
         # Train base learner
         learn.fine_tune(50, freeze_epochs=2)
         learn.save(baseModel)
+        if not os.path.exists(outputPath):
+            os.makedirs(outputPath)
         shutil.copy(path+os.sep+'models'+os.sep+baseModel+'.pth',outputPath)
 
         # supervised method
@@ -45,7 +48,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.save(outputPath+os.sep+targetModel)
+        learn2.save(targetModel)
         shutil.copy(path+os.sep+'models' + os.sep + targetModel + '.pth', outputPath)
         shutil.rmtree(path+'_tmp')
 
