@@ -13,6 +13,7 @@ import sys
 import os
 from efficientnet_pytorch import EfficientNet
 import importlib
+import sys
 
 
 availableModels=['ResNet18','ResNet50','ResNet101','EfficientNet','FBNet','MixNet','MNasNet','MobileNet','SqueezeNet','ShuffleNet']
@@ -120,10 +121,13 @@ def plainSupervised(path,pathUnlabelled,learn,th):
         newPath = path[:i] + "_tmp"
     else:
         newPath = path + "_tmp"
-    shutil.copytree(path, newPath)
+    if not os.path.exists(newPath):
+        shutil.copytree(path, newPath)
+    else:
+        raise NamedError("The path "+newPath+" already exists")
     for image in images:
         pn=learn.predict(image)
-        if pn[2][pn[2].argmax]>th:
+        if pn[2][pn[2].argmax()]>th:
             shutil.copyfile(image,newPath+os.sep+'train'+os.sep+pn[0]+os.sep+pn[0]+'_'+image.split(os.sep)[-1])
             print(image+" --> "+newPath+os.sep+'train'+os.sep+pn[0]+os.sep+pn[0]+'_'+image.split(os.sep)[-1])
 
